@@ -30,11 +30,11 @@ XML::Grammar::Fortune - convert the FortunesXML grammar to other formats and fro
 
 =head1 VERSION
 
-Version 0.0400
+Version 0.0500
 
 =cut
 
-our $VERSION = '0.0400';
+our $VERSION = '0.0500';
 
 
 =head1 SYNOPSIS
@@ -247,13 +247,18 @@ sub run
     return;
 }
 
+1; # End of XML::Grammar::Fortune
+
+__END__
+
 =head2 open
 
-Meant to settle Pod::Coverage - introduced by Fatal. Ignore.
+This function is introduced by Fatal. It is mentioned here, in order to settle 
+L<Pod::Coverage> . Ignore.
 
 =head1 AUTHOR
 
-Shlomi Fish, C<< <shlomif at iglu.org.il> >>
+Shlomi Fish, L<http://www.shlomifish.org/> .
 
 =head1 BUGS
 
@@ -261,9 +266,6 @@ Please report any bugs or feature requests to C<bug-xml-grammar-fortune at rt.cp
 the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=XML-Grammar-Fortune>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
-
-
-
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
@@ -296,13 +298,33 @@ L<http://search.cpan.org/dist/XML-Grammar-Fortune>
 
 =head1 ACKNOWLEDGEMENTS
 
-
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2008 Shlomi Fish, all rights reserved.
+Copyright 2008 by Shlomi Fish
 
-This program is released under the following license: MIT X11.
+This program is distributed under the MIT (X11) License:
+L<http://www.opensource.org/licenses/mit-license.php>
+
+Permission is hereby granted, free of charge, to any person
+obtaining a copy of this software and associated documentation
+files (the "Software"), to deal in the Software without
+restriction, including without limitation the rights to use,
+copy, modify, merge, publish, distribute, sublicense, and/or sell
+copies of the Software, and to permit persons to whom the
+Software is furnished to do so, subject to the following
+conditions:
+
+The above copyright notice and this permission notice shall be
+included in all copies or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
+OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
+NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
+HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
+WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
+FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
+OTHER DEALINGS IN THE SOFTWARE.
 
 =cut
 
-1; # End of XML::Grammar::Fortune
