@@ -27,16 +27,29 @@ XML::Grammar::Fortune::ToText - convert the FortunesXML grammar to plaintext.
 
 =head1 VERSION
 
-Version 0.0400
+Version 0.0500
 
 =cut
 
-our $VERSION = '0.0400';
+our $VERSION = '0.0500';
 
 
 =head1 SYNOPSIS
 
-TODO : Fill in.
+    use XML::Grammar::Fortune::ToText;
+
+    open my $out_fh, '>', 'my-fortunes.txt'
+        or die "Cannot open 'my-fortunes.txt' for writing - $!";
+    my $converter = XML::Grammar::Fortune::ToText->new(
+        {
+            'input' => "my-fortunes.fortune-xml.xml",
+            'output' => $out_fh,
+        }
+    );
+
+    $converter->run();
+
+    close($out_fh);
 
 =head1 FUNCTIONS
 
@@ -481,7 +494,7 @@ sub _append_different_formatting_node
 }
 
 {
-    my @_highlights = (['/', [qw(em i)]], ['*', [qw(b strong)]]);
+    my @_highlights = (['/', [qw(em i italics)]], ['*', [qw(b bold strong)]]);
 
     my %_formats_map =
     (
@@ -801,3 +814,75 @@ sub _render_info_node
 
 1;
 
+__END__
+
+=head1 AUTHOR
+
+Shlomi Fish, L<http://www.shlomifish.org/> .
+
+=head1 BUGS
+
+Please report any bugs or feature requests to C<bug-xml-grammar-fortune at rt.cpan.org>, or through
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=XML-Grammar-Fortune>.  I will be notified, and then you'll
+automatically be notified of progress on your bug as I make changes.
+
+=head1 SUPPORT
+
+You can find documentation for this module with the perldoc command.
+
+    perldoc XML::Grammar::Fortune
+
+
+You can also look for information at:
+
+=over 4
+
+=item * RT: CPAN's request tracker
+
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=XML-Grammar-Fortune>
+
+=item * AnnoCPAN: Annotated CPAN documentation
+
+L<http://annocpan.org/dist/XML-Grammar-Fortune>
+
+=item * CPAN Ratings
+
+L<http://cpanratings.perl.org/d/XML-Grammar-Fortune>
+
+=item * Search CPAN
+
+L<http://search.cpan.org/dist/XML-Grammar-Fortune>
+
+=back
+
+=head1 ACKNOWLEDGEMENTS
+
+=head1 COPYRIGHT & LICENSE
+
+Copyright 2008 by Shlomi Fish
+
+This program is distributed under the MIT (X11) License:
+L<http://www.opensource.org/licenses/mit-license.php>
+
+Permission is hereby granted, free of charge, to any person
+obtaining a copy of this software and associated documentation
+files (the "Software"), to deal in the Software without
+restriction, including without limitation the rights to use,
+copy, modify, merge, publish, distribute, sublicense, and/or sell
+copies of the Software, and to permit persons to whom the
+Software is furnished to do so, subject to the following
+conditions:
+
+The above copyright notice and this permission notice shall be
+included in all copies or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
+OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
+NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
+HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
+WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
+FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
+OTHER DEALINGS IN THE SOFTWARE.
+
+=cut
